@@ -76,7 +76,7 @@ func TestFmtStringDoesntLeakConfidentialValues(t *testing.T) {
 	value := NewConfidentialValue("secret")
 	value.hideValue()
 
-	assert.Equal(t, ConfidentialReplacement, fmt.Sprintf("%s", value))
+	assert.Equal(t, ConfidentialReplacement, value.String())
 	assert.Equal(t, ConfidentialReplacement, fmt.Sprintf("%v", value))
 	assert.Equal(t, ConfidentialReplacement, value.String())
 	assert.Equal(t, "secret", value.Value())
@@ -227,7 +227,7 @@ profile:
 	buffer := &bytes.Buffer{}
 	assert.Nil(t, ShowStruct(buffer, profile, "p"))
 
-	result := regexp.MustCompile("\\s+").ReplaceAllString(buffer.String(), " ")
+	result := regexp.MustCompile(`\s+`).ReplaceAllString(buffer.String(), " ")
 	result = strings.TrimSpace(result)
 
 	assert.Contains(t, result, "my_value: val")
