@@ -11,7 +11,7 @@ import (
 func TestSaveSingleBackup(t *testing.T) {
 	p := NewMetrics("test", "", "", nil)
 	p.BackupResults(StatusSuccess, monitor.Summary{
-		Duration:   time.Duration(11 * time.Second),
+		Duration:   11 * time.Second,
 		BytesAdded: 100,
 		BytesTotal: 1000,
 	})
@@ -22,7 +22,7 @@ func TestSaveSingleBackup(t *testing.T) {
 func TestSaveSingleBackupWithConfigLabel(t *testing.T) {
 	p := NewMetrics("test", "", "", map[string]string{"test_label": "test_value"})
 	p.BackupResults(StatusSuccess, monitor.Summary{
-		Duration:   time.Duration(11 * time.Second),
+		Duration:   11 * time.Second,
 		BytesAdded: 100,
 		BytesTotal: 1000,
 	})
@@ -33,7 +33,7 @@ func TestSaveSingleBackupWithConfigLabel(t *testing.T) {
 func TestSaveBackupGroup(t *testing.T) {
 	p := NewMetrics("test", "group", "", nil)
 	p.BackupResults(StatusSuccess, monitor.Summary{
-		Duration:   time.Duration(11 * time.Second),
+		Duration:   11 * time.Second,
 		BytesAdded: 100,
 		BytesTotal: 1000,
 	})
