@@ -5,7 +5,6 @@ package schtasks
 import (
 	"errors"
 	"fmt"
-	"math"
 	"os/user"
 	"strings"
 	"text/tabwriter"
@@ -60,8 +59,8 @@ var (
 	userPassword = ""
 )
 
-// ErrorNotConnected is returned by public functions if Connect was not called, was not successful or Close closed the connection.
-var ErrorNotConnected = errors.New("local task scheduler not connected")
+// ErrNotConnected is returned by public functions if Connect was not called, was not successful or Close closed the connection.
+var ErrNotConnected = errors.New("local task scheduler not connected")
 
 // IsConnected returns whether a connection to the local task scheduler is established
 func IsConnected() bool {
@@ -86,7 +85,7 @@ func Close() {
 // Create or update a task (if the name already exists in the Task Scheduler)
 func Create(config *Config, schedules []*calendar.Event, permission Permission) error {
 	if !IsConnected() {
-		return ErrorNotConnected
+		return ErrNotConnected
 	}
 
 	if permission == SystemAccount {
@@ -514,14 +513,14 @@ func createMonthlyTrigger(task *taskmaster.Definition, schedule *calendar.Event)
 // Delete a task
 func Delete(title, subtitle string) error {
 	if !IsConnected() {
-		return ErrorNotConnected
+		return ErrNotConnected
 	}
 
 	taskName := getTaskPath(title, subtitle)
 	err := taskService.DeleteTask(taskName)
 	if err != nil {
 		if strings.Contains(err.Error(), "doesn't exist") {
-			return fmt.Errorf("%w: %s", ErrorNotRegistered, taskName)
+			return fmt.Errorf("%w: %s", ErrNotRegistered, taskName)
 		}
 		return err
 	}
@@ -531,19 +530,19 @@ func Delete(title, subtitle string) error {
 // Status returns the status of a task
 func Status(title, subtitle string) error {
 	if !IsConnected() {
-		return ErrorNotConnected
+		return ErrNotConnected
 	}
 
 	taskName := getTaskPath(title, subtitle)
 	registeredTask, err := taskService.GetRegisteredTask(taskName)
 	if err != nil {
 		// if there's an error here, it is very likely that the task is not registered
-		return fmt.Errorf("%s: %w: %s", taskName, ErrorNotRegistered, err)
+		return fmt.Errorf("%s: %w: %s", taskName, ErrNotRegistered, err)
 	}
 	writer := tabwriter.NewWriter(term.GetOutput(), 2, 2, 2, ' ', tabwriter.AlignRight)
 	fmt.Fprintf(writer, "Task:\t %s\n", registeredTask.Path)
 	fmt.Fprintf(writer, "User:\t %s\n", registeredTask.Definition.Principal.UserID)
-	if registeredTask.Definition.Actions != nil && len(registeredTask.Definition.Actions) > 0 {
+	if len(registeredTask.Definition.Actions) > 0 {
 		if action, ok := registeredTask.Definition.Actions[0].(taskmaster.ExecAction); ok {
 			fmt.Fprintf(writer, "Working Dir:\t %v\n", action.WorkingDir)
 			fmt.Fprintf(writer, "Exec:\t %v\n", action.Path+" "+action.Args)
@@ -589,18 +588,18 @@ func compileDifferences(recurrences []time.Time) ([]time.Duration, []time.Durati
 	return differences, compactDifferences
 }
 
-func convertWeekdaysToBitmap(weekdays []int) int {
+func convertWeekdaysToBitmap(weekdays []int) uint16 {
 	if len(weekdays) == 0 {
 		return 0
 	}
-	bitmap := 0
+	var bitmap uint16
 	for _, weekday := range weekdays {
 		bitmap |= getWeekdayBit(weekday)
 	}
 	return bitmap
 }
 
-func getWeekdayBit(weekday int) int {
+func getWeekdayBit(weekday int) uint16 {
 	switch weekday {
 	case 0:
 		return 1
@@ -623,32 +622,36 @@ func getWeekdayBit(weekday int) int {
 	return 0
 }
 
-func convertMonthsToBitmap(months []int) int {
+func convertMonthsToBitmap(months []int) uint16 {
 	if months == nil {
 		return 0
 	}
 	if len(months) == 0 {
 		// all values
-		return int(math.Exp2(12)) - 1
+		return (1 << 12) - 1
 	}
-	bitmap := 0
+	var bitmap uint16
 	for _, month := range months {
-		bitmap |= int(math.Exp2(float64(month - 1)))
+		if month > 0 && month <= 12 {
+			bitmap |= 1 << (month - 1)
+		}
 	}
 	return bitmap
 }
 
-func convertDaysToBitmap(days []int) int {
+func convertDaysToBitmap(days []int) uint32 {
 	if days == nil {
 		return 0
 	}
 	if len(days) == 0 {
 		// every day
-		return int(math.Exp2(31)) - 1
+		return (1 << 31) - 1
 	}
-	bitmap := 0
+	var bitmap uint32
 	for _, day := range days {
-		bitmap |= int(math.Exp2(float64(day - 1)))
+		if day > 0 && day <= 31 {
+			bitmap |= 1 << (day - 1)
+		}
 	}
 	return bitmap
 }
